@@ -1,3 +1,22 @@
+/**
+ * QuickFlickr - FlickrClient for mobile devices.
+ *
+ * Author: Marko Mattila (marko.mattila@d-pointer.com)
+ *         http://www.d-pointer.com
+ *
+ *  QuickFlickr is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  QuickFlickr is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with QuickFLickr.  If not, see <http://www.gnu.org/licenses/>.
+ */
 #include "flickrmanager.h"
 
 
@@ -10,29 +29,40 @@
 #include <QMapIterator>
 #include <QVariant>
 
+#define KEY "cfa0d40dee57a1808c8c3c9b30f56ded"
+#define SECRET "72c539e938abdfc0"
 
 class FlickrManagerPrivate{
 public:
     FlickrManagerPrivate():
             m_qtFlickr(0),
             m_requestId(),
-            m_settings("QuickFlickr","Authorization"),
+            m_settings("d-pointer","quickflickr"),
             m_frob()
-    {
+    {            
     }
 
-    QSettings & settings(){
+    QSettings & settings()
+    {
         return m_settings;
     }
 
-    QString settingsValue(QString const & key) const{
+    QString settingsValue(QString const & key) const
+    {
         return m_settings.value(key).toString();
     }
 
-    void setSettingsValue(QString const & key, QString const & value){
+    void setSettingsValue(QString const & key, QString const & value)
+    {
         m_settings.setValue(key, value);
     }
 
+    void removeKey(QString const & key)
+    {
+        m_settings.remove(key);
+    }
+
+
     QtFlickr * m_qtFlickr;
     QHash<int, FlickrManager::RequestId> m_requestId;    
     QSettings        m_settings;
@@ -57,8 +87,7 @@ FlickrManager:: ~ FlickrManager()
 void FlickrManager::activate()
 {
     Q_D(FlickrManager);
-    d->m_qtFlickr = new QtFlickr ( "5ed969460703ab6ae4f0ecbf4178be5d",
-                                   "ee829960cd89d099", this );
+    d->m_qtFlickr = new QtFlickr ( KEY, SECRET, this );
 
     connect(d->m_qtFlickr,SIGNAL(requestFinished ( int, QtfResponse, QtfError, void* )),
             this,SLOT(requestFinished ( int, QtfResponse, QtfError, void* )));
@@ -69,13 +98,20 @@ void FlickrManager::activate()
     QString token = d->settingsValue("token");
     if(!token.isEmpty()){
         d->m_qtFlickr->setToken(token);                
-        emit proceed();
+        emit proceed();        
     }else{
         authenticate();        
     }
     
 }
 
+void FlickrManager::removeAuthentication()
+{
+    Q_D(FlickrManager);
+    d->removeKey("token");
+    authenticate();
+}
+
 void FlickrManager::authenticate()
 {    
     QtfMethod method;
@@ -86,42 +122,58 @@ void FlickrManager::authenticate()
     d->m_requestId.insert(d->m_qtFlickr->get(method,request), GetFrob);
 }
 
+void FlickrManager::getContacts()
+{
+    Q_D(FlickrManager);
+    QtfMethod method("flickr.contacts.getList");
+    method.args.insert("user_id", d->settingsValue("nsid"));
+    QtfRequest request;
+    d->m_requestId.insert(d->m_qtFlickr->post( method, request,0,false ), GetContacts);
+}
+
 
 void FlickrManager::getLatestContactUploads()
 {
     Q_D(FlickrManager);    
     QtfMethod method("flickr.photos.getContactsPublicPhotos");
     method.args.insert("user_id", d->settingsValue("nsid"));
-    method.args.insert("count", "30" );
+    method.args.insert("count", "20" );
     method.args.insert("include_self", "1");
     method.args.insert("single_photo", "true");
-    method.args.insert("extras", "date_taken" );    
+    //method.args.insert("extras", "date_taken" );
     QtfRequest request;
     d->m_requestId.insert(d->m_qtFlickr->post( method, request,0,false ), GetContactsPublicPhotos);    
 
 }
 
-void FlickrManager::getPhotosOfContact(const QString & userId)
+void FlickrManager::getPhotostream(const QString & userId, int page)
 {
     // Clear the old stuff    
     Q_D(FlickrManager);    
-    
-    qDebug() << "getPhotosOfContact() Method";
-    QtfMethod method("flickr.people.getPublicPhotos");
-    method.args.insert("api_key", "ee829960cd89d099");
-    method.args.insert("user_id", userId);
-    method.args.insert("extras", "description,date_taken,username,original_format,last_update,geo,tags,o_dims,views,url_m" );
-    method.args.insert("per_page","30");    
+        
+    qDebug() << "getPhotosOfContact() Method" << userId << page;
+    QtfMethod method("flickr.people.getPublicPhotos");    
+    method.args.insert("user_id", userId);    
+    method.args.insert("extras", "owner_name,url_m,url_s" );
+    method.args.insert("per_page","20");
+    method.args.insert("page", QString::number(page));
     QtfRequest request;
     d->m_requestId.insert(d->m_qtFlickr->post( method,request,0,false ), GetPhotosOfContact);
 }
 
+void FlickrManager::getUserInfo( const QString & userId )
+{
+    Q_D(FlickrManager);
+    QtfMethod method("flickr.people.getInfo");    
+    method.args.insert("user_id", userId);
+    QtfRequest request;
+    d->m_requestId.insert(d->m_qtFlickr->post( method,request,0,false ), GetUserInfo);
+}
 
 void FlickrManager::getRecentActivity()
 {
     Q_D(FlickrManager);
-    QtfMethod method("flickr.activity.userPhotos");    
-    method.args.insert("api_key", "ee829960cd89d099");    
+    QtfMethod method("flickr.activity.userPhotos");        
     method.args.insert("timeframe","30d");
     method.args.insert("per_page","30");    
     QtfRequest request;
@@ -147,8 +199,7 @@ void FlickrManager::getToken()
 
 void FlickrManager::getComments(const QString & photoId)
 {
-    QtfMethod method("flickr.photos.comments.getList");    
-    method.args.insert("api_key", "ee829960cd89d099");    
+    QtfMethod method("flickr.photos.comments.getList");        
     method.args.insert("photo_id", photoId);
     QtfRequest request;    
     Q_D(FlickrManager);
@@ -156,9 +207,8 @@ void FlickrManager::getComments(const QString & photoId)
 }
     
 void FlickrManager::addComment(const QString & photoId, const QString & commentText )
-{
-    QtfMethod method("flickr.photos.comments.addComment");    
-    method.args.insert("api_key", "ee829960cd89d099");    
+{    
+    QtfMethod method("flickr.photos.comments.addComment");        
     method.args.insert("photo_id", photoId);
     method.args.insert("comment_text", commentText);
     QtfRequest request;    
@@ -168,8 +218,7 @@ void FlickrManager::addComment(const QString & photoId, const QString & commentT
 
 void FlickrManager::addFavorite( const QString & photoId )
 {
-    QtfMethod method("flickr.favorites.add");    
-    method.args.insert("api_key", "ee829960cd89d099");    
+    QtfMethod method("flickr.favorites.add");          
     method.args.insert("photo_id", photoId);    
     QtfRequest request;    
     Q_D(FlickrManager);
@@ -177,11 +226,12 @@ void FlickrManager::addFavorite( const QString & photoId )
 }
 
 
-void FlickrManager::getFavorites()
+void FlickrManager::getFavorites(int perPage, int page)
 {
-    QtfMethod method("flickr.favorites.getList");    
-    method.args.insert("api_key", "ee829960cd89d099");        
-    method.args.insert("extras","url_m,owner_name");
+    QtfMethod method("flickr.favorites.getList");             
+    method.args.insert("extras","url_s,owner_name");
+    method.args.insert("per_page", QString::number(perPage));
+    method.args.insert("page", QString::number(page));
     QtfRequest request;    
     Q_D(FlickrManager);
     d->m_requestId.insert(d->m_qtFlickr->post( method,request,0,false ), GetFavorites); 
@@ -189,14 +239,35 @@ void FlickrManager::getFavorites()
 
 void FlickrManager::removeFavorite( const QString & photoId )
 {
-    QtfMethod method("flickr.favorites.remove");    
-    method.args.insert("api_key", "ee829960cd89d099");        
+    QtfMethod method("flickr.favorites.remove");         
     method.args.insert("photo_id",photoId);
     QtfRequest request;    
     Q_D(FlickrManager);
     d->m_requestId.insert(d->m_qtFlickr->post( method,request,0,false ), RemoveFavorite); 
 }
 
+
+void FlickrManager::getPhotoInfo(const QString & photoId )
+{
+    QtfMethod method("flickr.photos.getInfo");    
+    method.args.insert("photo_id", photoId);
+    QtfRequest request;
+    Q_D(FlickrManager);
+    d->m_requestId.insert(d->m_qtFlickr->post( method,request,0,false ), GetPhotoInfo);
+}
+
+QString FlickrManager::nsid() const
+{
+    Q_D(const FlickrManager);
+    return d->settingsValue("nsid");
+}
+
+QString FlickrManager::userName() const
+{
+    Q_D(const FlickrManager);
+    return d->settingsValue("username");
+}
+
 void FlickrManager::requestFinished ( int reqId, QtfResponse data, QtfError err, void* userData )
 {
     Q_UNUSED( userData );
@@ -252,13 +323,18 @@ void FlickrManager::requestFinished ( int reqId, QString xmlData, QtfError err,
         emit contactsUploadsUpdated(xmlData);                                
         break;
 
+    case GetContacts:
+        //qDebug() << xmlData;
+        emit contactsUpdated(xmlData);
+        break;
+
     case GetPhotosOfContact:
         //qDebug() << xmlData;
         emit photostreamUpdated(xmlData);
         break;        
         
     case GetRecentActivity:        
-        //qDebug() << xmlData;
+        qDebug() << xmlData;
         emit recentActivityUpdated(xmlData);
         break;
         
@@ -278,7 +354,7 @@ void FlickrManager::requestFinished ( int reqId, QString xmlData, QtfError err,
         break;
         
     case GetFavorites:
-        qDebug() << xmlData;
+        //qDebug() << xmlData;
         emit favoritesUpdated(xmlData);
         break;
     
@@ -286,10 +362,21 @@ void FlickrManager::requestFinished ( int reqId, QString xmlData, QtfError err,
         emit favoriteRemoved();
         break;
         
+    case GetUserInfo:
+        qDebug()<< xmlData;
+        emit userInfoUpdated(xmlData);
+        break;
+    case GetPhotoInfo:
+        //qDebug()<< xmlData;
+        emit photoInfoUpdated(xmlData);
+        break;
+
     default:
         {
             if ( !err.code){
                 qWarning()<<"Error: "<<err.message;
+            }else{
+                qWarning() << "Unknown Request!";
             }
         }
         break;
